==> htmx-1.8.2.jar: META-INF/resources/webjars/htmx/www/essays.md <==
---
layout: layout.njk
title: </> htmx - Essays
---

## Essays

* [How Did REST Come To Mean The Opposite of REST?](/essays/how-did-rest-come-to-mean-the-opposite-of-rest/)
* [Hypermedia-Driven Applications (HDAs)](/essays/hypermedia-driven-applications)
* [HATEOAS](/essays/hateoas)
* [Locality of Behavior (LoB)](/essays/locality-of-behaviour)
* [Splitting Your Data & Application APIs: Going Further](/essays/splitting-your-apis)
* [Hypermedia APIs vs. Data APIs](/essays/hypermedia-apis-vs-data-apis)
* [Complexity Budget](/essays/complexity-budget)
* [SPA Alternative](/essays/spa-alternative)
* [A Response To "Have SPA's Ruined The Web"](/essays/a-response-to-rich-harris)
* [Template Fragments](/essays/template-fragments/)


### Older [intercooler.js](https://intercoolerjs.org) Essays

* [Taking HTML Seriously](https://intercoolerjs.org/2020/01/14/taking-html-seriously)
* [HATEOAS Is For Humans](https://intercoolerjs.org/2016/05/08/hatoeas-is-for-humans.html)
* [The API Churn/Security Trade-off](https://intercoolerjs.org/2016/02/17/api-churn-vs-security.html)
* [Rescuing REST From the API Winter](https://intercoolerjs.org/2016/01/18/rescuing-rest.html)

### Grug

* [The Grug Brained Developer](https://grugbrain.dev)

## Memes

<style>
  .memes {
    text-align: center;
  }
  .memes img {
     max-width: 100%;
     margin: 16px;
   }
</style>
<div class="memes">
<img src="/img/memes/original.png">
<img src="/img/memes/20yearold.png">
<img src="/img/memes/extinction.png">
<img src="/img/memes/restapi.png">
<img src="/img/memes/whowillwin.png">
<img src="/img/memes/frontenddevs.png">
<img src="/img/memes/htmxanddjango.png">
<img src="/img/memes/htmlvsjson.png">
<img src="/img/memes/bellcurve.png">
<img src="/img/memes/aye.png">
<img src="/img/memes/justusehtml.png">
<img src="/img/memes/dontknowwhatclientsideroutingis.png">
<img src="/img/memes/drakearchitecture.png">
<img src="/img/memes/nocap.png">
<img src="/img/memes/ie11enjoyer.png">
<img src="/img/memes/hydration.png">
<img src="/img/memes/viewsource.png">
<img src="/img/memes/javascripthistory.png">
<img src="/img/memes/bellcurve2.png">
<img src="/img/memes/dbtohtml.png">
<img src="/img/memes/normal.png">
<img src="/img/memes/uarealldoingitwrong.png">
<img src="/img/memes/feelbad.png">
<img src="/img/memes/drakememes.png">
</div>

==> htmx-1.8.4.jar: META-INF/resources/webjars/htmx/www/essays.md <==
---
layout: layout.njk
title: </> htmx - Essays
---

## Essays

* [When To Use Hypermedia?](/essays/when-to-use-hypermedia/)
* [A Real World React to htmx Port](/essays/a-real-world-react-to-htmx-port/)
* [How Did REST Come To Mean The Opposite of REST?](/essays/how-did-rest-come-to-mean-the-opposite-of-rest/)
* [Hypermedia-Driven Applications (HDAs)](/essays/hypermedia-driven-applications)
* [HATEOAS](/essays/hateoas)
* [Locality of Behavior (LoB)](/essays/locality-of-behaviour)
* [Splitting Your Data & Application APIs: Going Further](/essays/splitting-your-apis)
* [Hypermedia APIs vs. Data APIs](/essays/hypermedia-apis-vs-data-apis)
* [Complexity Budget](/essays/complexity-budget)
* [SPA Alternative](/essays/spa-alternative)
* [A Response To "Have SPA's Ruined The Web"](/essays/a-response-to-rich-harris)
* [Template Fragments](/essays/template-fragments/)


### Older [intercooler.js](https://intercoolerjs.org) Essays

* [Taking HTML Seriously](https://intercoolerjs.org/2020/01/14/taking-html-seriously)
* [HATEOAS Is For Humans](https://intercoolerjs.org/2016/05/08/hatoeas-is-for-humans.html)
* [The API Churn/Security Trade-off](https://intercoolerjs.org/2016/02/17/api-churn-vs-security.html)
* [Rescuing REST From the API Winter](https://intercoolerjs.org/2016/01/18/rescuing-rest.html)

### Grug

* [The Grug Brained Developer](https://grugbrain.dev)

## Memes

<style>
  .memes {
    text-align: center;
  }
  .memes img {
     max-width: 100%;
     margin: 16px;
   }
</style>
<div class="memes">
<img src="/img/memes/original.png">
<img src="/img/memes/20yearold.png">
<img src="/img/memes/extinction.png">
<img src="/img/memes/restapi.png">
<img src="/img/memes/whowillwin.png">
<img src="/img/memes/frontenddevs.png">
<img src="/img/memes/htmxanddjango.png">
<img src="/img/memes/htmlvsjson.png">
<img src="/img/memes/bellcurve.png">
<img src="/img/memes/aye.png">
<img src="/img/memes/justusehtml.png">
<img src="/img/memes/dontknowwhatclientsideroutingis.png">
<img src="/img/memes/drakearchitecture.png">
<img src="/img/memes/nocap.png">
<img src="/img/memes/ie11enjoyer.png">
<img src="/img/memes/hydration.png">
<img src="/img/memes/viewsource.png">
<img src="/img/memes/javascripthistory.png">
<img src="/img/memes/bellcurve2.png">
<img src="/img/memes/dbtohtml.png">
<img src="/img/memes/normal.png">
<img src="/img/memes/uarealldoingitwrong.png">
<img src="/img/memes/feelbad.png">
<img src="/img/memes/drakememes.png">
<img src="/img/memes/fullstack.jpg">
</div>
